@@ -3,7 +3,7 @@ import pandas as pd
 from datetime import datetime, timedelta
 from fbprophet import Prophet
 
-from decomp import generic_yearly_decomp, generic_weekly_decomp, generic_daily_decomp
+from tank_forecaster.decomp import generic_yearly_decomp, generic_weekly_decomp, generic_daily_decomp
 
 
 def gen_future(df, periods=30, freq='1D'):
